/*
 * appres.h : External defs for files needing the application
 *	resources.
 *
 * George Ferguson, ferguson@cs.rochester.edu, 12 Sep 1991.
 *
 */

#ifndef APP_RESOURCES_H
#define APP_RESOURCES_H

#include "types.h"		/* for SearchType and SortType */

typedef struct {
    String	widgets;
    SearchType	searchType;
    SortType	sortType;
    String	archieHost;
    int		maxHits;
    int		offset;
    int		timeout;
    int		retries;
    int		niceLevel;
    String	ftpDir;
    String	ftpType;
    int		debugLevel;
    String	settingsWidgets;
} AppResources;

extern AppResources appResources;

#endif /* APP_RESOURCES_H */
